data {
    int N;
    real X[N];
    real Y[N];
    real Z[N];
}
parameters {
    real muX;
    real muY;
    real muZ;
    real<lower = 0.0> sgmX;
    real<lower = 0.0> sgmY;
    real<lower = 0.0> sgmZ;
    corr_matrix[3] cor;
}
transformed parameters {
    real RhoXY;
    real RhoXZ;
    real RhoYZ;
    cov_matrix[3] Cov;
    Cov[1][1] = sgmX*sgmX;
    Cov[1][2] = cor[1][2]*sgmX*sgmY;
    Cov[1][3] = cor[1][3]*sgmX*sgmZ;
    Cov[2][1] = cor[2][1]*sgmY*sgmX;
    Cov[2][2] = sgmY*sgmY;
    Cov[2][3] = cor[2][3]*sgmY*sgmZ;
    Cov[3][1] = cor[3][1]*sgmX*sgmZ;
    Cov[3][2] = cor[3][2]*sgmY*sgmZ;
    Cov[3][3] = sgmZ*sgmZ;
    RhoXY = cor[1][2];
    RhoXZ = cor[1][3];
    RhoYZ = cor[2][3];
}
model {
    muX ~ normal(0.0, 1000.0);
    muY ~ normal(0.0, 1000.0);
    muZ ~ normal(0.0, 1000.0);
    sgmX ~ exponential(0.001);
    sgmY ~ exponential(0.001);
    sgmZ ~ exponential(0.001);
    cor ~ lkj_corr(1.0);
    for (i in 1:N) {
        [X[i], Y[i], Z[i]] ~ multi_normal([muX, muY, muZ], Cov);
    }
}
