data {
    int N;
    real X[N];
    real Y[N];
    real Z[N];
}
parameters {
    real mu1;
    real mu2;
    real<lower = 0.0> sgm1;
    real<lower = 0.0> sgm2;
    real<lower = 0.0> sgm_x;
    real<lower = 0.0> sgm_y;
    real<lower = -1.0, upper = 1.0> rho; 
    real Ax;
    real Bx;
    real Ay;
    real By;
}
transformed parameters {
    vector[2] XY[N];
    for (i in 1:N) {
        XY[i][1] = X[i] - (Bx + Ax * Z[i]); 
        XY[i][2] = Y[i] - (By + Ay * Z[i]);   
    }
}
model {
    mu1 ~ normal(0.0, 100.0);
    mu2 ~ normal(0.0, 100.0);
    sgm1 ~ exponential(0.001);
    sgm2 ~ exponential(0.001);
    rho ~ uniform(-1.0, 1.0);
    Ax ~ normal(0.0, 1000.0);
    Ay ~ normal(0.0, 1000.0);
    Bx ~ normal(0.0, 1000.0);
    By ~ normal(0.0, 1000.0);
    sgm_x ~ exponential(0.001);
    sgm_y ~ exponential(0.001);
    for (i in 1:N) {
        X[i] ~ normal(Bx + Ax * Z[i], sgm_x);
        Y[i] ~ normal(By + Ay * Z[i], sgm_y);
        XY[i] ~ multi_normal([mu1, mu2], [[sgm1*sgm1, rho*sgm1*sgm2], [rho*sgm2*sgm1, sgm2*sgm2]]);
    }
}